=======================================
ISLE pronunciation dictionary accessors
=======================================


.. image:: https://img.shields.io/pypi/v/islex.svg
        :target: https://pypi.python.org/pypi/islex

.. image:: https://img.shields.io/travis/jkahn/islex.svg
        :target: https://travis-ci.org/jkahn/islex

.. image:: https://readthedocs.org/projects/islex/badge/?version=latest
        :target: https://islex.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/jkahn/islex/shield.svg
     :target: https://pyup.io/repos/github/jkahn/islex/
     :alt: Updates


Utility classes to support easy extraction and manipulation of
dictionary-to-pronunciation from the ISLE dictionary.


* Free software: MIT license
* Documentation: https://islex.readthedocs.io.


Features
--------

* Loading and navigating around the data structures of the ISLE lexicon.

Credits
---------

Package author is `Jeremy G Kahn`_, repackaging the very useful `ISLE
pronunciation lexicon`_ from the `Illinois Speech and Language
Engineering`_ group.

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _`Jeremy G Kahn`: http://trochee.net/
.. _`ISLE pronunciation lexicon`: http://isle.illinois.edu/sst/data/g2ps/English/ISLEdict.txt
.. _`Illinois Speech and Language Engineering`: http://www.isle.illinois.edu
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

